// Lesson 10 - lesson10EconPointClass.js

/* 
* An eEconPoint "class" automatically extends the Object type and "has a" 
*   x-coordinate representing the quantity of an item
*   y-coordinate reprsenting the price of an item
* and has the following methods defined:
*   isEqualQuantity(otherQ) // determines if this quantity is same as another quantity
*   isEqualPrice(otherP)    // determines if this price is the same as another price
*   toString()		    // to allow EconPoint objects to print out as coordinate pairs (0,0)
*/

// good programming practice includes following
// strict programming guidelines
"use strict"

/** Declare a constructor method with two parameter objects.*/
function EconPointClass(q,p) {

	// Do a simple check in parameters and throw an error if not passed numbers
	if (isNaN(p) || isNaN(q)) {
		throw new TypeError();
	}
	
	// Properties storing the quantity & price of "this" object
	// Approximating Java's instance (field) variables.
 	this.quantity = q;
	this.price    = p;
	
	// TOLERANCE is "how close" two prices (or quantities) must remain to be considered "equal".
	// Approximating Java's static class fields.
	// the tolerance can be set to any desired value and is abitrarily set to 0.1
	EconPointClass.TOLERANCE = 0.1; 
}

/** Using the "prototype" property effectively makes EconPoint extends Object.
* Syntax Note: The use of commas as list separators as opposed to semicolons as statement terminators.
*/
EconPointClass.prototype = {
	
	/** Returns true if the the parameter otherQ has the same quantity as this object's quantity.
	* Equivelent to Java's instance method. 
	*/
	isEqualQuantity: function(otherQ) { 
		return (Math.abs(this.quantity - otherQ)< EconPointClass.TOLERANCE)
	},

	/** Returns true if the the parameter otherP has the same price as this object's price.
	* Approximating Java's instance method. 
	*/
	isEqualPrice: function(otherP) { 
		return (Math.abs(this.price - otherP) < EconPointClass.TOLERANCE)
	},
	
	/** The toString() method allows EconPoints to be printed as coordinate pair in parenthesis.  
	* Example: (0.0, 0.0) 
	* Approximating Java's overloading/overwriting Object's inherited toString() method
	*/
	toString: function() {
		return ("(" + this.quantity + ", " + this.price + ")");
	}
};





