// Lesson 5, JavaScript and the Document Object Model SOLUTIONS

// Good programming practice includes following strict programming guidelines
// "use strict" also helps find Syntax Errors that would otherwise fail silently
"use strict"

/* Global (aka window) variables are initialized in the initRed() method. */
var currentState;	// The currentState holds the "model"
var userInterface;	// The userInterface represents the "view"

function myMainMethod() {
	init();
}

function init(newShade) {

	userInterface =  {
		headingIdRed: 	null,
		promptIdRed: 	null,
		inputIdRed: 	null,
		percentIdRed: 	null,
		numberIdRed: 	null,
		lowIdRed: 	null,
		highIdRed: 	null,
		
		headingIdBlue: 	null,
		promptIdBlue: 	null,
		inputIdBlue: 	null,
		percentIdBlue: 	null,
		numberIdBlue: 	null,
		lowIdBlue: 	null,
		highIdBlue: 	null
	};

	for (var id in userInterface) {
		userInterface[id] = document.getElementById(id);
	}

	currentState = {
		valueRed: Math.floor(Math.random()*100)+1,  
		valueBlue: Math.floor(Math.random()*100)+1,	
		numberOfTriesRed: 0,
		numberOfTriesBlue: 0,				
		previousRed: undefined,
		previousBlue: undefined				
	};

	userInterface.inputIdRed.onchange = handleNewRedShade;	
	userInterface.inputIdBlue.onchange = handleNewBlueShade;

	window.onpopstate = getHistoryState;
	modifyWebPage(currentState);
}

function setHistory(oldState) {
	
	if (!history.pushState) {
		alert ("cannot push to the history object");
		return; 
	}

	var url = "#previous" + oldState.previousRed + oldState.previousBlue;
	history.pushState(oldState, "", url);
}

function getHistoryState(event) {


	if (event.state != null) {
		currentState = event.state;
		modifyWebPage(currentState);
	}
	else {
		history.replaceState(currentState, "", "#previous" + currentState.previousRed + currentState.previousBlue);
	}
}

function handleNewRedShade() {

	var value = parseInt(this.value); 	
		
	if ((value > 0) && (value <= 100)) {
		currentState.previousRed = currentState.valueRed;
		currentState.valueRed = value;
		currentState.numberOfTriesRed++;
		setHistory(currentState);
		modifyWebPage(currentState);
	}
	else {
		alert("Please enter a number between 0 and 100");
	}
}

function handleNewBlueShade() {

	var value = parseInt(this.value); 	
		
	if ((value > 0) && (value <= 100)) {
		currentState.previousBlue = currentState.valueBlue;
		currentState.valueBlue = value;
		currentState.numberOfTriesBlue++;
		setHistory(currentState);
		modifyWebPage(currentState);
	}
	else {
		alert("Please enter a number between 0 and 100");
	}
}

function modifyWebPage(newState) {

	document.title = "Try a shade between 0 and 100";
	userInterface.headingIdRed.innerHTML = document.title;

	userInterface.percentIdRed.innerHTML = "Red at " + newState.valueRed +" %";
	userInterface.numberIdRed.innerHTML  = "Number of red shades attempted: "+newState.numberOfTriesRed;	
	userInterface.percentIdBlue.innerHTML = "Blue at " + newState.valueBlue +" %";
	userInterface.numberIdBlue.innerHTML  = "Number of blue shades attempted: "+newState.numberOfTriesBlue;
	
	var byteColorRed = new Number(newState.valueRed/100.0 * 255);
	byteColorRed = byteColorRed.toFixed(0); 

	var byteColorBlue = new Number(newState.valueBlue/100.0 * 255);
	byteColorBlue = byteColorBlue.toFixed(0); 

	userInterface.lowIdRed.style = "background-color:rgb("+byteColorRed+",0,0)";
	userInterface.lowIdBlue.style = "background-color:rgb(0,0,"+byteColorBlue+")";

	// NOTE: Some browsers may have difficulty with the above statement for setting the color style.
	// 	 The next line (along with the 'helper' methods below may be used instead.	
	//userInterface.lowIdRed.style.backgroundColor = rgbToHexColor(byteColorRed,0,0);

	userInterface.lowIdRed.style.width = newState.valueRed +"%";
	userInterface.highIdRed.style.width = (100-newState.valueRed) + "%";
	userInterface.lowIdBlue.style.width = newState.valueBlue +"%";
	userInterface.highIdBlue.style.width = (100-newState.valueBlue) + "%";

	userInterface.inputIdRed.value = "";
	userInterface.inputIdRed.focus();
	userInterface.inputIdBlue.value = "";
	userInterface.inputIdBlue.focus();

	if (newState.previousRed === undefined) {
		userInterface.promptIdRed.innerHTML = "Type in a shade of RED and hit Enter";
	}
	else if (newState.previousRed > 100) {
		userInterface.promptIdRed.innerHTML = "too high, try a number less than  or equal to 100";
	}
	else if (newState.previousRed < 0) {
		userInterface.promptIdRed.innerHTML = "too low, try a number greater than 0";
	}
	else {
		userInterface.promptIdRed.innerHTML = "Enter a new shade of RED";
	}

	if (newState.previousBlue === undefined) {
		userInterface.promptIdBlue.innerHTML = "Type in a shade of BLUE and hit Enter";
	}
	else if (newState.previousBlue > 100) {
		userInterface.promptIdBlue.innerHTML = "too high, try a number less than  or equal to 100";
	}
	else if (newState.previousBlue < 0) {
		userInterface.promptIdBlue.innerHTML = "too low, try a number greater than 0";
	}
	else {
		userInterface.promptIdBlue.innerHTML = "Enter a new shade of BLUE";
	}
}

/**
* The following two functions are "helper" functions to convert color integer values into
* hexidecimal values that browsers use for styling purposes. 
* 
* THE CONVERSIONS ARE BEYOND THE SCOPE OF LESSON 5
*/
function rgbToHexColor(red,green,blue)  {
    	return "#" + byteToHex(red) + byteToHex(green) + byteToHex(blue);
}
function byteToHex(value) {
	var hexidecimalCharacters 	= "0123456789ABCDEF";
	var grabLeft4Bits 		= value >> 4;
	var getLeftHexDigit 		= grabLeft4Bits & 0x0F;
	var firstHexCharacter 		= hexidecimalCharacters.substr(getLeftHexDigit,1)
	var getRightHexDigit 		= value & 0x0F;
	var secondHexCharacter  	= hexidecimalCharacters.substr(getRightHexDigit,1)
   	return String(firstHexCharacter + secondHexCharacter) ;
}
	
