// Lesson 8 Debugging JavaScript

// Good programming practice includes following strict programming guidelines
// "use strict" also helps find Syntax Errors that would otherwise fail silently
"use strict"

function swapImages() {
	// No errors to get the first image from the DOM	
	var firstImage  = window.document.getElementById("AceClubs");
	console.log(firstImage);

	/* Error Type 1: JavaScript SYNTAX ERROR, forgetting an assignment (=).
	* 		 Console error message will "assume" that there is a missing semicolon (;)
	* 		 after declaration of the secondImage variable.
	*  DEBUG BY COMMENTING OUT THE NEXT LINE
	*/
	var secondImage   window.document.getElementById("twoClubs");

	// Error Type 1: Correct Syntax 
	var secondImage = window.document.getElementById("twoClubs");

	
	/* Error Type 2: JavaScript RUNTIME ERROR, misspelling a function name.
	*		 May generate a Console Error for a generic "TypeError"
	*		 May generate a Debugger Error where an Exception variable can be inspected.
	*		 Often caused by trying to access an object (method/property)
	*		 that does not exist in the DOM.
	*  DEBUG BY COMMENTING OUT THE NEXT 2 LINES
	*/
	alert("the next line has a Runtime Error");
	var thirdImage 	= window.document.getElementByID("threeClubs");
	
	// Error Type 2: Correct RunTime method call 	
	var thirdImage 	= window.document.getElementById("threeClubs");


	/* Error Type 3: JavaScript LOGIC ERROR, not swapping the intended images.
	*		 No Console messages but the X/HTML does not display 
	*		 swapped/rotated images as expected.  Instead, it duplicates
	*		 one of the images.
	*  DEBUG BY COMMENTING OUT THE NEXT 3 LINES
	*/
	firstImage.src  = secondImage.src;
	secondImage.src = thirdImage.src
	thirdImage.src 	= firstImage.src;

	// Error Type 3: Correct logic to swap to rotate the images 	
	var temp 	= firstImage.src;
	firstImage.src 	= secondImage.src;
	secondImage.src = thirdImage.src
	thirdImage.src 	= temp;
}

/** The following code is an older approach to debugging scripts prior to the 
*   Developers Tools in browsers.  It will not catch Syntax Errors but can
*   detect many Runtime Errors.
*/
/*
window.onerror = function (msg, url, line) {
	alert("ERROR: " +msg + "\n" 
			+url + "\n"
			+"line: "+line);
	return true;
}
*/

