// Lesson 9, Part 1, Sequence C

// good programming practice includes following
// strict guidelines
"use strict"

function myMainMethod() {

	// 1. Create the single FORM object use throughout all methods below.
	// This form object will be passed as a parameter to each method.
	var myFormObject = document.createElement("FORM");
	
	// 2. Call the myAddElementToForm() method to create text box in the form.
	myAddElementToForm(myFormObject, "TEXTAREA", "default search text");

	// 3. Call the same method but create radio buttons to the same form.
	myAddElementToForm(myFormObject, "INPUT", "apples", "radio" );
	myAddElementToForm(myFormObject, "INPUT", "oranges", "radio" );
	myAddElementToForm(myFormObject, "INPUT", "bananas", "radio" );
		
	// 4. Call the same method but create checkboxe using a loop.
	for (var i = 1; i<5; i++) {
		myAddElementToForm(myFormObject, "INPUT", "Option "+i, "checkbox" );
	}
	
	// 5. Call the myAddSelectionsToForm() method to add a list (array) of options
	// to a <SELECT> tag.
	myAddSelectionsToForm(myFormObject, "SELECT", ["lizards", "snakes", "crocodiles", "salamanders"] );
	
	// 6. Call the myAddElementToForm() method to create a button on the form.
	myAddElementToForm(myFormObject, "BUTTON", "Submit Form");
}


/*
* The myAddElementToForm() method allows up to four parameters for flexibility.
* The formParameter should reference an already existing form object. 
* The elementParameter object will be used to create the appropriate element object.
* The textParameter is to be used for any text that needs to be displayed in the browser.
* The elementType is "radio" or "checkbox" or "" or left blank if not needed for other elements. 
*/
function myAddElementToForm(formParameter, elementParameter, textParameter, elementType) {
	
	// 1. Check to make sure the parameter objects exists, if not, then create the form.
	if (formParameter==null) {
		var formParameter = document.createElement("FORM");
	}
	
	// 2. Check the existence of the elementParameter. 
	// If the parameter is null then we won't know which tag to add 
	// to the form so we must return immediately.
	if (elementParameter == null) {
		 return;
	}
	else {
		
		// 3. Create the element object.
		var myElementInForm = document.createElement(elementParameter);
		
		// 4. [Optional] Wrap the element inside a <DIV> tag so that it shows up on 
		// a separate line in the browser.
		var myDiv	= document.createElement("DIV");
		myDiv.appendChild(myElementInForm);
		
		// 5. If text is wanted (i.e. included as a parameter, then add the text to the element.
		if (textParameter != null) {
			var myElementText = document.createTextNode(textParameter);
			myElementInForm.appendChild(myElementText);
		}
		
		// 6. If there is an element type such as radio or checkbox, then
		// add the type to the element's "type=" attribute then add the element to the <DIV> tag.
		// NOTE: the "radio" and "checkbox" are case-sensitive..."RADIO" or "CheckBox" will not work.
		if ((elementType != null) || (elementType == "radio")  || (elementType == "checkbox")) {
			myElementInForm.setAttribute("type", elementType);
			myDiv.appendChild(myElementText);  // [OPTIONAL]
		}
	}

	// 7. Add the <DIV> to the form and then the form to the document body.
	formParameter.appendChild(myDiv);
	document.body.appendChild(formParameter);
}

/*
* The myAddSelectionsToForm() method is similar to the myAddElementToForm() method.
* However, instead of adding one element object one at a time, this method uses a parameter
* containing a list of options to add an array of <SELECT> options
*/
function myAddSelectionsToForm(formParameter, inputElement, optionList) {
	
	// 1. check to make sure the parameter objects exists, if not, then create one.
	if (formParameter==null) {
		var formParameter = document.createElement("FORM");
	}
	
	// 2. Create the select object (eg. <SELECT> </SELECT> tag) 
	var mySelectToForm	= document.createElement("SELECT");	
	
	// 3. [OPTIONAL] Wrap the element inside a <DIV> tag so that it shows up on 
	// a separate line in the browser. 
	var myDiv				= document.createElement("DIV");
	myDiv.appendChild(mySelectToForm);
			
	// 4. Go through the optionList array, one option at a time.
	for (var i=0; i<optionList.length; i++){
		
		// 4a. Create each option object (eg. <OPTION value="optionX">option</OPTION> tag).
		var myOption = document.createElement("OPTION");
		myOption.setAttribute("value",optionList[i]);
		
		// 4b. Create the same text information to display.
		var myText = document.createTextNode(optionList[i]);
		myOption.appendChild(myText);
		
		// 4c. add the option to the <SELECT> tag
		mySelectToForm.appendChild(myOption);
	}
		
	// 5. Add the <SELECT> tag to the <DIV> then add the <DIV> tag
	//    to the <FORM> tag which is finally added to the <BODY> tag
	myDiv.appendChild(mySelectToForm);
	formParameter.appendChild(myDiv);
	document.body.appendChild(formParameter);	
}

